package com.ruoyi.project.asset.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.asset.mapper.TLeakagePointsPatrolMapper;
import com.ruoyi.project.asset.domain.TLeakagePointsPatrol;
import com.ruoyi.project.asset.service.ITLeakagePointsPatrolService;

/**
 * 漏点巡检Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-01
 */
@Service
public class TLeakagePointsPatrolServiceImpl implements ITLeakagePointsPatrolService 
{
    @Autowired
    private TLeakagePointsPatrolMapper tLeakagePointsPatrolMapper;

    /**
     * 查询漏点巡检
     * 
     * @param id 漏点巡检主键
     * @return 漏点巡检
     */
    @Override
    public TLeakagePointsPatrol selectTLeakagePointsPatrolById(Long id)
    {
        return tLeakagePointsPatrolMapper.selectTLeakagePointsPatrolById(id);
    }

    /**
     * 查询漏点巡检列表
     * 
     * @param tLeakagePointsPatrol 漏点巡检
     * @return 漏点巡检
     */
    @Override
    public List<TLeakagePointsPatrol> selectTLeakagePointsPatrolList(TLeakagePointsPatrol tLeakagePointsPatrol)
    {
        return tLeakagePointsPatrolMapper.selectTLeakagePointsPatrolList(tLeakagePointsPatrol);
    }

    /**
     * 新增漏点巡检
     * 
     * @param tLeakagePointsPatrol 漏点巡检
     * @return 结果
     */
    @Override
    public int insertTLeakagePointsPatrol(TLeakagePointsPatrol tLeakagePointsPatrol)
    {
        return tLeakagePointsPatrolMapper.insertTLeakagePointsPatrol(tLeakagePointsPatrol);
    }

    /**
     * 修改漏点巡检
     * 
     * @param tLeakagePointsPatrol 漏点巡检
     * @return 结果
     */
    @Override
    public int updateTLeakagePointsPatrol(TLeakagePointsPatrol tLeakagePointsPatrol)
    {
        return tLeakagePointsPatrolMapper.updateTLeakagePointsPatrol(tLeakagePointsPatrol);
    }

    /**
     * 批量删除漏点巡检
     * 
     * @param ids 需要删除的漏点巡检主键
     * @return 结果
     */
    @Override
    public int deleteTLeakagePointsPatrolByIds(Long[] ids)
    {
        return tLeakagePointsPatrolMapper.deleteTLeakagePointsPatrolByIds(ids);
    }

    /**
     * 删除漏点巡检信息
     * 
     * @param id 漏点巡检主键
     * @return 结果
     */
    @Override
    public int deleteTLeakagePointsPatrolById(Long id)
    {
        return tLeakagePointsPatrolMapper.deleteTLeakagePointsPatrolById(id);
    }
}
